@@ -7,7 +7,7 @@
 #             ANY CHANGE MADE HERE WILL BE LOST !
 #
 ####################################################################
-package XDR::Parse v0.1.1;
+package XDR::Parse v0.1.2;
 use vars qw ( @ISA );
 use strict;
 
@@ -29,20 +29,20 @@ sub new {
 [
 	{#State 0
 		ACTIONS => {
-			"struct" => 1,
-			"union" => 9,
-			'PREPROC' => 2,
-			"enum" => 11,
-			'PASSTHROUGH' => 4,
-			"const" => 6,
-			"typedef" => 7
+			"typedef" => 10,
+			"union" => 12,
+			'PASSTHROUGH' => 11,
+			"enum" => 2,
+			"const" => 1,
+			'PREPROC' => 8,
+			"struct" => 3
 		},
 		GOTOS => {
-			'typeDef' => 3,
-			'specification' => 12,
-			'definitions' => 8,
-			'constantDef' => 10,
-			'definition' => 5
+			'specification' => 9,
+			'typeDef' => 5,
+			'constantDef' => 6,
+			'definitions' => 7,
+			'definition' => 4
 		}
 	},
 	{#State 1
@@ -51,317 +51,317 @@ sub new {
 		}
 	},
 	{#State 2
-		DEFAULT => -6
-	},
-	{#State 3
-		DEFAULT => -7
-	},
-	{#State 4
-		DEFAULT => -5
-	},
-	{#State 5
 		ACTIONS => {
-			"enum" => 11,
-			'PASSTHROUGH' => 4,
-			'PREPROC' => 2,
-			"struct" => 1,
-			"union" => 9,
-			"typedef" => 7,
-			"const" => 6
-		},
-		DEFAULT => -3,
-		GOTOS => {
-			'definition' => 5,
-			'typeDef' => 3,
-			'constantDef' => 10,
-			'definitions' => 14
+			'IDENT' => 14
 		}
 	},
-	{#State 6
+	{#State 3
 		ACTIONS => {
 			'IDENT' => 15
 		}
 	},
-	{#State 7
+	{#State 4
 		ACTIONS => {
-			"char" => 18,
-			"struct" => 20,
-			"quadruple" => 19,
-			'IDENT' => 17,
-			"enum" => 29,
-			"long" => 27,
-			"short" => 34,
-			"union" => 33,
-			"double" => 32,
-			"float" => 30,
-			"hyper" => 31,
-			"string" => 21,
-			"int" => 25,
-			"unsigned" => 26,
-			"bool" => 24,
-			"opaque" => 23,
-			"void" => 22
+			"const" => 1,
+			'PREPROC' => 8,
+			"enum" => 2,
+			"struct" => 3,
+			"typedef" => 10,
+			"union" => 12,
+			'PASSTHROUGH' => 11
 		},
+		DEFAULT => -3,
 		GOTOS => {
-			'typeSpecifier' => 28,
-			'declaration' => 16
+			'definition' => 4,
+			'typeDef' => 5,
+			'constantDef' => 6,
+			'definitions' => 16
 		}
 	},
-	{#State 8
+	{#State 5
+		DEFAULT => -7
+	},
+	{#State 6
+		DEFAULT => -8
+	},
+	{#State 7
 		ACTIONS => {
-			'TRAILING_COMMENT' => 35
+			'TRAILING_COMMENT' => 17
 		},
 		DEFAULT => -1
 	},
+	{#State 8
+		DEFAULT => -6
+	},
 	{#State 9
 		ACTIONS => {
-			'IDENT' => 36
+			'' => 18
 		}
 	},
 	{#State 10
-		DEFAULT => -8
+		ACTIONS => {
+			"float" => 24,
+			"int" => 25,
+			"short" => 26,
+			"void" => 21,
+			"hyper" => 23,
+			"enum" => 22,
+			"char" => 19,
+			"struct" => 20,
+			"long" => 34,
+			"opaque" => 35,
+			'IDENT' => 37,
+			"unsigned" => 36,
+			"bool" => 33,
+			"union" => 32,
+			"string" => 29,
+			"double" => 28,
+			"quadruple" => 30
+		},
+		GOTOS => {
+			'typeSpecifier' => 31,
+			'declaration' => 27
+		}
 	},
 	{#State 11
-		ACTIONS => {
-			'IDENT' => 37
-		}
+		DEFAULT => -5
 	},
 	{#State 12
 		ACTIONS => {
-			'' => 38
+			'IDENT' => 38
 		}
 	},
 	{#State 13
 		ACTIONS => {
-			"{" => 40
-		},
-		GOTOS => {
-			'structBody' => 39
+			"=" => 39
 		}
 	},
 	{#State 14
-		DEFAULT => -4
+		ACTIONS => {
+			"{" => 40
+		},
+		GOTOS => {
+			'enumBody' => 41
+		}
 	},
 	{#State 15
 		ACTIONS => {
-			"=" => 41
-		}
-	},
-	{#State 16
-		ACTIONS => {
-			";" => 42
-		}
-	},
-	{#State 17
-		DEFAULT => -47
-	},
-	{#State 18
-		DEFAULT => -32
-	},
-	{#State 19
-		DEFAULT => -42
-	},
-	{#State 20
-		ACTIONS => {
-			"{" => 40
+			"{" => 42
 		},
 		GOTOS => {
 			'structBody' => 43
 		}
 	},
-	{#State 21
+	{#State 16
+		DEFAULT => -4
+	},
+	{#State 17
+		DEFAULT => -2
+	},
+	{#State 18
+		DEFAULT => 0
+	},
+	{#State 19
+		DEFAULT => -32
+	},
+	{#State 20
 		ACTIONS => {
-			'IDENT' => 44
+			"{" => 42
+		},
+		GOTOS => {
+			'structBody' => 44
 		}
 	},
-	{#State 22
+	{#State 21
 		DEFAULT => -60
 	},
-	{#State 23
+	{#State 22
 		ACTIONS => {
-			'IDENT' => 45
+			"{" => 40
+		},
+		GOTOS => {
+			'enumBody' => 45
 		}
 	},
+	{#State 23
+		DEFAULT => -38
+	},
 	{#State 24
-		DEFAULT => -43
+		DEFAULT => -40
 	},
 	{#State 25
 		DEFAULT => -30
 	},
 	{#State 26
-		ACTIONS => {
-			"hyper" => 48,
-			"int" => 50,
-			"short" => 47,
-			"char" => 46,
-			"long" => 49
-		}
+		DEFAULT => -34
 	},
 	{#State 27
-		DEFAULT => -36
+		ACTIONS => {
+			";" => 46
+		}
 	},
 	{#State 28
-		ACTIONS => {
-			'IDENT' => 51,
-			"*" => 52
-		}
+		DEFAULT => -41
 	},
 	{#State 29
 		ACTIONS => {
-			"{" => 53
-		},
-		GOTOS => {
-			'enumBody' => 54
+			'IDENT' => 47
 		}
 	},
 	{#State 30
-		DEFAULT => -40
+		DEFAULT => -42
 	},
 	{#State 31
-		DEFAULT => -38
-	},
-	{#State 32
-		DEFAULT => -41
-	},
-	{#State 33
 		ACTIONS => {
-			"switch" => 56
-		},
-		GOTOS => {
-			'switch' => 55
+			"*" => 49,
+			'IDENT' => 48
 		}
 	},
+	{#State 32
+		ACTIONS => {
+			"switch" => 51
+		},
+		GOTOS => {
+			'switch' => 50
+		}
+	},
+	{#State 33
+		DEFAULT => -43
+	},
 	{#State 34
-		DEFAULT => -34
+		DEFAULT => -36
 	},
 	{#State 35
-		DEFAULT => -2
+		ACTIONS => {
+			'IDENT' => 52
+		}
 	},
 	{#State 36
 		ACTIONS => {
-			"switch" => 56
-		},
-		GOTOS => {
-			'switch' => 57
+			"hyper" => 56,
+			"long" => 53,
+			"short" => 55,
+			"char" => 57,
+			"int" => 54
 		}
 	},
 	{#State 37
-		ACTIONS => {
-			"{" => 53
-		},
-		GOTOS => {
-			'enumBody' => 58
-		}
+		DEFAULT => -47
 	},
 	{#State 38
-		DEFAULT => 0
+		ACTIONS => {
+			"switch" => 51
+		},
+		GOTOS => {
+			'switch' => 58
+		}
 	},
 	{#State 39
 		ACTIONS => {
-			";" => 59
+			'CONST' => 60,
+			'IDENT' => 59
 		}
 	},
 	{#State 40
 		ACTIONS => {
-			"enum" => 29,
-			"long" => 27,
-			"short" => 34,
-			"double" => 32,
-			"union" => 33,
-			"hyper" => 31,
-			"float" => 30,
-			"string" => 21,
-			"bool" => 24,
-			"unsigned" => 26,
-			"int" => 25,
-			"void" => 22,
-			"opaque" => 23,
-			"char" => 18,
-			"struct" => 20,
-			"quadruple" => 19,
-			'IDENT' => 17
+			'IDENT' => 61
 		},
 		GOTOS => {
-			'structItem' => 62,
-			'structItems' => 61,
-			'declaration' => 60,
-			'typeSpecifier' => 28
+			'enumItems' => 62,
+			'enumItem' => 63
 		}
 	},
 	{#State 41
 		ACTIONS => {
-			'CONST' => 63,
-			'IDENT' => 64
+			";" => 64
 		}
 	},
 	{#State 42
-		DEFAULT => -9
+		ACTIONS => {
+			"quadruple" => 30,
+			"string" => 29,
+			"double" => 28,
+			"union" => 32,
+			"bool" => 33,
+			"unsigned" => 36,
+			'IDENT' => 37,
+			"opaque" => 35,
+			"long" => 34,
+			"struct" => 20,
+			"char" => 19,
+			"hyper" => 23,
+			"enum" => 22,
+			"void" => 21,
+			"short" => 26,
+			"int" => 25,
+			"float" => 24
+		},
+		GOTOS => {
+			'structItems' => 66,
+			'declaration' => 65,
+			'structItem' => 67,
+			'typeSpecifier' => 31
+		}
 	},
 	{#State 43
-		DEFAULT => -45
+		ACTIONS => {
+			";" => 68
+		}
 	},
 	{#State 44
-		ACTIONS => {
-			"<" => 65
-		}
+		DEFAULT => -45
 	},
 	{#State 45
-		ACTIONS => {
-			"<" => 66,
-			"[" => 67
-		}
+		DEFAULT => -44
 	},
 	{#State 46
-		DEFAULT => -33
+		DEFAULT => -9
 	},
 	{#State 47
-		DEFAULT => -35
+		ACTIONS => {
+			"<" => 69
+		}
 	},
 	{#State 48
-		DEFAULT => -39
-	},
-	{#State 49
-		DEFAULT => -37
-	},
-	{#State 50
-		DEFAULT => -31
-	},
-	{#State 51
 		ACTIONS => {
-			"[" => 68,
-			"<" => 69
+			"<" => 70,
+			"[" => 71
 		},
 		DEFAULT => -50
 	},
+	{#State 49
+		ACTIONS => {
+			'IDENT' => 72
+		}
+	},
+	{#State 50
+		DEFAULT => -46
+	},
+	{#State 51
+		ACTIONS => {
+			"(" => 73
+		}
+	},
 	{#State 52
 		ACTIONS => {
-			'IDENT' => 70
+			"[" => 74,
+			"<" => 75
 		}
 	},
 	{#State 53
-		ACTIONS => {
-			'IDENT' => 72
-		},
-		GOTOS => {
-			'enumItem' => 73,
-			'enumItems' => 71
-		}
+		DEFAULT => -37
 	},
 	{#State 54
-		DEFAULT => -44
+		DEFAULT => -31
 	},
 	{#State 55
-		DEFAULT => -46
+		DEFAULT => -35
 	},
 	{#State 56
-		ACTIONS => {
-			"(" => 74
-		}
+		DEFAULT => -39
 	},
 	{#State 57
-		ACTIONS => {
-			";" => 75
-		}
+		DEFAULT => -33
 	},
 	{#State 58
 		ACTIONS => {
@@ -369,199 +369,207 @@ sub new {
 		}
 	},
 	{#State 59
-		DEFAULT => -11
-	},
-	{#State 60
 		ACTIONS => {
 			";" => 77
 		}
 	},
+	{#State 60
+		ACTIONS => {
+			";" => 78
+		}
+	},
 	{#State 61
 		ACTIONS => {
-			"}" => 78
+			"=" => 79
 		}
 	},
 	{#State 62
 		ACTIONS => {
-			"float" => 30,
-			"hyper" => 31,
-			"union" => 33,
-			"double" => 32,
-			"short" => 34,
-			"long" => 27,
-			"enum" => 29,
-			"void" => 22,
-			"opaque" => 23,
-			"unsigned" => 26,
-			"bool" => 24,
-			"int" => 25,
-			"string" => 21,
-			"quadruple" => 19,
-			"struct" => 20,
-			"char" => 18,
-			'IDENT' => 17
-		},
-		DEFAULT => -23,
-		GOTOS => {
-			'declaration' => 60,
-			'structItems' => 79,
-			'typeSpecifier' => 28,
-			'structItem' => 62
+			"}" => 80
 		}
 	},
 	{#State 63
 		ACTIONS => {
-			";" => 80
-		}
+			"," => 81
+		},
+		DEFAULT => -27
 	},
 	{#State 64
-		ACTIONS => {
-			";" => 81
-		}
+		DEFAULT => -10
 	},
 	{#State 65
 		ACTIONS => {
-			">" => 85,
-			'CONST' => 84,
-			'IDENT' => 83
-		},
-		GOTOS => {
-			'value' => 82
+			";" => 82
 		}
 	},
 	{#State 66
 		ACTIONS => {
-			">" => 86,
-			'CONST' => 84,
-			'IDENT' => 83
-		},
-		GOTOS => {
-			'value' => 87
+			"}" => 83
 		}
 	},
 	{#State 67
 		ACTIONS => {
-			'CONST' => 84,
-			'IDENT' => 83
+			"char" => 19,
+			"struct" => 20,
+			"void" => 21,
+			"hyper" => 23,
+			"enum" => 22,
+			"int" => 25,
+			"float" => 24,
+			"short" => 26,
+			"string" => 29,
+			"double" => 28,
+			"quadruple" => 30,
+			"union" => 32,
+			"bool" => 33,
+			"opaque" => 35,
+			"long" => 34,
+			'IDENT' => 37,
+			"unsigned" => 36
 		},
+		DEFAULT => -23,
 		GOTOS => {
-			'value' => 88
+			'structItems' => 84,
+			'declaration' => 65,
+			'typeSpecifier' => 31,
+			'structItem' => 67
 		}
 	},
 	{#State 68
+		DEFAULT => -11
+	},
+	{#State 69
 		ACTIONS => {
-			'IDENT' => 83,
-			'CONST' => 84
+			'IDENT' => 87,
+			'CONST' => 86,
+			">" => 88
+		},
+		GOTOS => {
+			'value' => 85
+		}
+	},
+	{#State 70
+		ACTIONS => {
+			'IDENT' => 87,
+			'CONST' => 86,
+			">" => 90
 		},
 		GOTOS => {
 			'value' => 89
 		}
 	},
-	{#State 69
+	{#State 71
 		ACTIONS => {
-			'CONST' => 84,
-			">" => 90,
-			'IDENT' => 83
+			'CONST' => 86,
+			'IDENT' => 87
 		},
 		GOTOS => {
 			'value' => 91
 		}
 	},
-	{#State 70
-		DEFAULT => -59
-	},
-	{#State 71
-		ACTIONS => {
-			"}" => 92
-		}
-	},
 	{#State 72
-		ACTIONS => {
-			"=" => 93
-		}
+		DEFAULT => -59
 	},
 	{#State 73
 		ACTIONS => {
-			"," => 94
+			"bool" => 33,
+			"union" => 32,
+			"unsigned" => 36,
+			'IDENT' => 37,
+			"long" => 34,
+			"opaque" => 35,
+			"quadruple" => 30,
+			"string" => 29,
+			"double" => 28,
+			"short" => 26,
+			"float" => 24,
+			"int" => 25,
+			"struct" => 20,
+			"char" => 19,
+			"hyper" => 23,
+			"enum" => 22,
+			"void" => 21
 		},
-		DEFAULT => -27
+		GOTOS => {
+			'declaration' => 92,
+			'typeSpecifier' => 31
+		}
 	},
 	{#State 74
 		ACTIONS => {
-			"string" => 21,
-			"int" => 25,
-			"bool" => 24,
-			"unsigned" => 26,
-			"opaque" => 23,
-			"void" => 22,
-			"enum" => 29,
-			"long" => 27,
-			"short" => 34,
-			"hyper" => 31,
-			"float" => 30,
-			"double" => 32,
-			"union" => 33,
-			'IDENT' => 17,
-			"char" => 18,
-			"quadruple" => 19,
-			"struct" => 20
+			'CONST' => 86,
+			'IDENT' => 87
 		},
 		GOTOS => {
-			'declaration' => 95,
-			'typeSpecifier' => 28
+			'value' => 93
 		}
 	},
 	{#State 75
-		DEFAULT => -12
+		ACTIONS => {
+			'IDENT' => 87,
+			">" => 94,
+			'CONST' => 86
+		},
+		GOTOS => {
+			'value' => 95
+		}
 	},
 	{#State 76
-		DEFAULT => -10
+		DEFAULT => -12
 	},
 	{#State 77
-		DEFAULT => -25
-	},
-	{#State 78
-		DEFAULT => -22
-	},
-	{#State 79
-		DEFAULT => -24
-	},
-	{#State 80
-		DEFAULT => -13
-	},
-	{#State 81
 		DEFAULT => -14
 	},
-	{#State 82
+	{#State 78
+		DEFAULT => -13
+	},
+	{#State 79
 		ACTIONS => {
-			">" => 96
+			'CONST' => 86,
+			'IDENT' => 87
+		},
+		GOTOS => {
+			'value' => 96
 		}
 	},
+	{#State 80
+		DEFAULT => -26
+	},
+	{#State 81
+		ACTIONS => {
+			'IDENT' => 61
+		},
+		GOTOS => {
+			'enumItems' => 97,
+			'enumItem' => 63
+		}
+	},
+	{#State 82
+		DEFAULT => -25
+	},
 	{#State 83
-		DEFAULT => -49
+		DEFAULT => -22
 	},
 	{#State 84
-		DEFAULT => -48
+		DEFAULT => -24
 	},
 	{#State 85
-		DEFAULT => -57
+		ACTIONS => {
+			">" => 98
+		}
 	},
 	{#State 86
-		DEFAULT => -55
+		DEFAULT => -48
 	},
 	{#State 87
-		ACTIONS => {
-			">" => 97
-		}
+		DEFAULT => -49
 	},
 	{#State 88
-		ACTIONS => {
-			"]" => 98
-		}
+		DEFAULT => -57
 	},
 	{#State 89
 		ACTIONS => {
-			"]" => 99
+			">" => 99
 		}
 	},
 	{#State 90
@@ -569,79 +577,70 @@ sub new {
 	},
 	{#State 91
 		ACTIONS => {
-			">" => 100
+			"]" => 100
 		}
 	},
 	{#State 92
-		DEFAULT => -26
+		ACTIONS => {
+			")" => 101
+		}
 	},
 	{#State 93
 		ACTIONS => {
-			'CONST' => 84,
-			'IDENT' => 83
-		},
-		GOTOS => {
-			'value' => 101
+			"]" => 102
 		}
 	},
 	{#State 94
-		ACTIONS => {
-			'IDENT' => 72
-		},
-		GOTOS => {
-			'enumItem' => 73,
-			'enumItems' => 102
-		}
+		DEFAULT => -55
 	},
 	{#State 95
 		ACTIONS => {
-			")" => 103
+			">" => 103
 		}
 	},
 	{#State 96
-		DEFAULT => -58
-	},
-	{#State 97
-		DEFAULT => -56
-	},
-	{#State 98
-		DEFAULT => -54
-	},
-	{#State 99
-		DEFAULT => -51
-	},
-	{#State 100
-		DEFAULT => -53
-	},
-	{#State 101
 		DEFAULT => -29
 	},
-	{#State 102
+	{#State 97
 		DEFAULT => -28
 	},
-	{#State 103
+	{#State 98
+		DEFAULT => -58
+	},
+	{#State 99
+		DEFAULT => -53
+	},
+	{#State 100
+		DEFAULT => -51
+	},
+	{#State 101
 		ACTIONS => {
 			"{" => 104
 		}
 	},
+	{#State 102
+		DEFAULT => -54
+	},
+	{#State 103
+		DEFAULT => -56
+	},
 	{#State 104
 		ACTIONS => {
-			"case" => 107
+			"case" => 105
 		},
 		GOTOS => {
-			'caseClause' => 105,
 			'caseClauses' => 106,
-			'caseBody' => 108
+			'caseClause' => 108,
+			'caseBody' => 107
 		}
 	},
 	{#State 105
 		ACTIONS => {
-			"case" => 107
+			'IDENT' => 87,
+			'CONST' => 86
 		},
-		DEFAULT => -18,
 		GOTOS => {
-			'caseClauses' => 109,
-			'caseClause' => 105
+			'value' => 109
 		}
 	},
 	{#State 106
@@ -655,85 +654,86 @@ sub new {
 	},
 	{#State 107
 		ACTIONS => {
-			'CONST' => 84,
-			'IDENT' => 83
-		},
-		GOTOS => {
-			'value' => 112
+			"}" => 112
 		}
 	},
 	{#State 108
 		ACTIONS => {
-			"}" => 113
+			"case" => 105
+		},
+		DEFAULT => -18,
+		GOTOS => {
+			'caseClauses' => 113,
+			'caseClause' => 108
 		}
 	},
 	{#State 109
-		DEFAULT => -19
+		ACTIONS => {
+			":" => 114
+		}
 	},
 	{#State 110
 		ACTIONS => {
-			":" => 114
+			":" => 115
 		}
 	},
 	{#State 111
 		DEFAULT => -17
 	},
 	{#State 112
-		ACTIONS => {
-			":" => 115
-		}
+		DEFAULT => -15
 	},
 	{#State 113
-		DEFAULT => -15
+		DEFAULT => -19
 	},
 	{#State 114
 		ACTIONS => {
-			"char" => 18,
-			"struct" => 20,
-			"quadruple" => 19,
-			'IDENT' => 17,
-			"enum" => 29,
-			"long" => 27,
-			"short" => 34,
-			"union" => 33,
-			"double" => 32,
-			"hyper" => 31,
-			"float" => 30,
-			"string" => 21,
+			"short" => 26,
+			"float" => 24,
 			"int" => 25,
-			"unsigned" => 26,
-			"bool" => 24,
-			"void" => 22,
-			"opaque" => 23
+			"struct" => 20,
+			"char" => 19,
+			"hyper" => 23,
+			"enum" => 22,
+			"void" => 21,
+			"union" => 32,
+			"bool" => 33,
+			"unsigned" => 36,
+			'IDENT' => 37,
+			"opaque" => 35,
+			"long" => 34,
+			"quadruple" => 30,
+			"string" => 29,
+			"double" => 28
 		},
 		GOTOS => {
-			'typeSpecifier' => 28,
+			'typeSpecifier' => 31,
 			'declaration' => 116
 		}
 	},
 	{#State 115
 		ACTIONS => {
-			"long" => 27,
-			"enum" => 29,
-			"float" => 30,
-			"hyper" => 31,
-			"union" => 33,
-			"double" => 32,
-			"short" => 34,
-			"string" => 21,
-			"void" => 22,
-			"opaque" => 23,
-			"int" => 25,
-			"unsigned" => 26,
-			"bool" => 24,
-			"char" => 18,
-			"quadruple" => 19,
+			"quadruple" => 30,
+			"string" => 29,
+			"double" => 28,
+			"unsigned" => 36,
+			'IDENT' => 37,
+			"long" => 34,
+			"opaque" => 35,
+			"union" => 32,
+			"bool" => 33,
+			"hyper" => 23,
+			"enum" => 22,
+			"void" => 21,
 			"struct" => 20,
-			'IDENT' => 17
+			"char" => 19,
+			"short" => 26,
+			"float" => 24,
+			"int" => 25
 		},
 		GOTOS => {
-			'declaration' => 117,
-			'typeSpecifier' => 28
+			'typeSpecifier' => 31,
+			'declaration' => 117
 		}
 	},
 	{#State 116
@@ -747,10 +747,10 @@ sub new {
 		}
 	},
 	{#State 118
-		DEFAULT => -21
+		DEFAULT => -20
 	},
 	{#State 119
-		DEFAULT => -20
+		DEFAULT => -21
 	}
 ],
                                   yyrules  =>
@@ -1375,10 +1375,6 @@ sub parse {
 
 XDR::Parse - Creation of an AST of an XDR specification
 
-=head1 VERSION
-
-0.1.1
-
 =head1 SYNOPSIS
 
   use XDR::Parse;
@@ -1389,7 +1385,7 @@ XDR::Parse - Creation of an AST of an XDR specification
 
 =head1 VERSION
 
-0.0.1
+0.1.2
 
 =head1 DESCRIPTION
 
@@ -1495,7 +1491,7 @@ is detailed in the sections below.
 
 =head4 'typedef' declarations
 
-This node is a ´declaration' node as documented in the section
+This node is a 'declaration' node as documented in the section
 'declaration' nodes below.
 
 =head4 'enum' declarations
@@ -1618,6 +1614,8 @@ declarations above.
 
 =head1 LICENSE
 
+This distribution may be used under the same terms as Perl itself.
+
 =head1 AUTHOR
 
 =over 8
